/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2016  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#ifndef ENCODERINTERPOLATORHEADERFILE
#define ENCODERINTERPOLATORHEADERFILE

#include <vector>

#include "encoderchannel.h"
#include "../../core/vector2.h"

class TEncoderInterpolator
{
public:
	
// CREATORS
	TEncoderInterpolator(void);
	~TEncoderInterpolator(void);
	
// ACCESSORS
	std::vector<TVector2> Interpolate(const double &distance, const TEncoderChannel &cha, const TEncoderChannel &chb,bool *error) const;
	
// MANIPULATORS
	void Set_Data_Size(const int size) {d_data_size = size;}
	void Set_Interpolator_Count(const int count) {d_interpolator_count = count;}
	
private:
	int									d_data_size;
	int									d_interpolator_count;
	
	double Convert_Sin_Cos_To_Angle(const double &in_sin,const double &in_cos) const;
	int Compare_Angles(const double &angle,const double &reference_angle,const double &threshold) const;
	
// NOT IMPLEMENTED
	TEncoderInterpolator(const TEncoderInterpolator&);
	TEncoderInterpolator& operator=(const TEncoderInterpolator&);
};

#endif